@@ -1,3 +1,4 @@
+import contextlib
 import os
 
 from scandir import scandir
@@ -6,10 +7,8 @@ from scandir import scandir
 def scantree(path, include):
     res = []
 
-    try:
+    with contextlib.suppress(OSError):
         res = _scantree_rec(path, include, [])
-    except OSError:
-        pass
 
     return res
 
@@ -18,8 +17,7 @@ def _scantree_rec(path, include=[], files=[]):
     for entry in scandir(path):
         if entry.is_dir(follow_symlinks=False):
             _scantree_rec(entry.path, include, files)
-        elif entry.is_file():
-            if os.path.splitext(entry.path)[1][1:] in include:
-                files.append(entry.path)
+        elif entry.is_file() and os.path.splitext(entry.path)[1][1:] in include:
+            files.append(entry.path)
 
     return files
